@@ -19,6 +19,7 @@ import os, sys
 from datetime import datetime
 from threading import Thread
 import shutil
+import socket
 import functest
 functest.configure()
 
@@ -120,6 +121,21 @@ def configure_global_settings():
         local_settings = None
 
     windmill.settings = windmill.conf.configure_settings(localSettings=local_settings)
+    
+    port = windmill.settings['SERVER_HTTP_PORT']
+    
+    while 1:
+        try:
+            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            s.connect(('127.0.0.1', port))
+            s.close()
+            port += 1
+        except socket.error:
+            break
+    
+    windmill.settings['SERVER_HTTP_PORT'] = port
+    
+    return windmill.settings
 
 on_ide_awake = []
 
@@ -140,14 +156,14 @@ def setup():
     
     if windmill.settings['CONTINUE_ON_FAILURE'] is not False:
         shell_objects.jsonrpc_client.add_json_command('{"method": "commands.setOptions", "params": {"stopOnFailure" : false}}')
+        
+    if windmill.settings['EXTENSIONS_DIR'] is not None:
+        shell_objects.load_extensions_dir(windmill.settings['EXTENSIONS_DIR'])
                 
     if windmill.settings['RUN_TEST'] is not None:
         shell_objects.run_test(windmill.settings['RUN_TEST'])
     if windmill.settings['LOAD_TEST'] is not None:
         shell_objects.load_test(windmill.settings['LOAD_TEST'])
-        
-    if windmill.settings['EXTENSIONS_DIR'] is not None:
-        shell_objects.load_extensions_dir(windmill.settings['EXTENSIONS_DIR'])
          
     if windmill.settings['JAVASCRIPT_TEST_DIR']:
         shell_objects.run_js_tests(windmill.settings['JAVASCRIPT_TEST_DIR'], 
