@@ -21,7 +21,7 @@ windmill.ui.remote = new function() {
     this.selectedElementOption = null;
 
     this.scrollRecorderTextArea = function() {
-        var obj = $("ide");
+        var obj = $("ideForm");
         obj.scrollTop = obj.scrollHeight;
     };
 
@@ -90,6 +90,18 @@ windmill.ui.remote = new function() {
       this.selectedElement = null;
       this.selectedElementOption = id;
     };
+    
+    //This is because the google chrome rendering engine sucks
+    //and makes drop down boxes with background images black
+    this.addCSSBG = function(){
+      var is_chrome = /chrome/.test( navigator.userAgent.toLowerCase() );
+      if (!is_chrome){
+       var smallopts = jQuery(".smalloption") ;
+       for (i=0; i < smallopts.length; i++){
+         smallopts[i].style.background = 'transparent url("/windmill-serv/img/text_elem_gradient.gif")';
+       }
+      }
+    }
 
     this.addActionAbove = function(uuid) {
         var newAction = this.buildAction(null, {});
@@ -102,6 +114,7 @@ windmill.ui.remote = new function() {
         else {
           $(newAction.id + "locator").focus();
         }
+        this.addCSSBG();
         fleegix.fx.fadeIn($(newAction.id));
     };
 
@@ -115,6 +128,7 @@ windmill.ui.remote = new function() {
           var loc = $(action.id + "locator");
           if (loc){ loc.focus(); }
         }
+        this.addCSSBG();
         fleegix.fx.fadeIn($(action.id));
     };
 
@@ -140,6 +154,7 @@ windmill.ui.remote = new function() {
 
     this.addAction = function(action) {
         var suite = this.getSuite();
+        suite.style.height = '';
         if (typeof(action) == 'undefined') {
             var action = this.buildAction(null, {});
         }
@@ -152,6 +167,7 @@ windmill.ui.remote = new function() {
             try { $(action.id + "locator").focus(); }
             catch(err){}
         }
+        this.addCSSBG();
         return action.id;
 
     };
@@ -167,50 +183,79 @@ windmill.ui.remote = new function() {
         catch(err){alert('Please enter valid JSON');}
       }
     }
-
-    this.getSuite = function(suiteName) {
-
-        if (!suiteName) {
-            var suiteName = 'recordingSuite' + windmill.ui.recordSuiteNum;
+    
+    //Update all the required DOM to rename the suite
+    this.updateSuite = function(suiteName){
+      var newSN = prompt("New Suite Name?","");
+      if ((!newSN) || (newSN == "")){
+        return;
+      }
+      //make sure it's a legit suite name
+      newSN = newSN.replace(" ", "_");
+      var oldSuite = $(suiteName);  
+      oldSuite.id = newSN;
+      
+      //change all of the old suite names
+      var re = new RegExp(suiteName, "g");
+      jQuery(oldSuite).html(oldSuite.innerHTML.replace(re, newSN));
+      windmill.ui.currentSuite = newSN;
+    };
+    
+    this.getSuite = function(suiteName, newFlag) {
+        if (typeof(newFlag) == "undefined"){
+          var newFlag = false;
         }
-
+        //If what we really want is a new suite, the newFlag was passed
+        if (newFlag){
+          var suiteName = 'recordingSuite' + windmill.ui.recordSuiteNum;
+          windmill.ui.currentSuite = null;
+        }
+        //if not
+        else {
+          //if there is a current suite selected
+          if (windmill.ui.currentSuite){
+              var suiteName = windmill.ui.currentSuite;
+          }
+          //default to a new one
+          else {
+            var suiteName = 'recordingSuite' + windmill.ui.recordSuiteNum;
+          }
+        }
+          
         var suite = $(suiteName);
         if (suite == null) {
             var ide = $('ideForm');
             suite = document.createElement('div');
-            suite.style.position = 'relative';
+            suite.className = "suite";
             suite.id = suiteName;
-
-            if (windmill.browser.isIE) {
-                var vWidth = fleegix.dom.getViewportWidth();
-                suite.style.width = (vWidth - 22) + 'px';
-
-            }
-            else {
-                suite.style.width = "100%";
-            }
-            // suite.style.background = "#33CC99";
-            suite.style.overflow = 'hidden';
-            //suite.style.height='40px';
-            //suite.style.borderTop = '1px solid black';
-            suite.style.borderBottom = '1px solid black';
-
-            suite.innerHTML = "<table id='"+suiteName+"Header' style='padding:2px;width:100%;font-size:12px;'><tr><td><strong>Suite </strong>" + suiteName + 
-            "</td><td><span align=\"right\" style='top:0px;float:right;'><a href=\"#\" onclick=\"windmill.ui.playback.sendPlayBack(null,\'" + suiteName + 
-            "\')\">[play]</a>&nbsp<a href=\"#\" onclick=\"windmill.ui.remote.saveSuite(\'" + suiteName + 
-            "\')\">[save]</a>&nbsp<a href=\"#\" onclick=\"windmill.ui.remote.deleteAction(\'" + suiteName + 
-            "\')\">[delete]</a>&nbsp<a href=\"#\" onclick=\"javascript:windmill.ui.toggleCollapse(\'" + suiteName + 
-            "\')\">[hide/show]</a></span></td></tr></table>";
+            
+            suite.innerHTML = "<table id='"+suiteName+"Header'"+
+            "class='suiteHeader'><tr><td style=\"font-size:13px;\"><strong style='cursor:all-scroll'>Suite </strong><span class='suiteTitleDiv' title='"+suiteName+
+            "' id='"+suiteName+"Title' onclick=\"windmill.ui.remote.updateSuite(\'"+
+            suiteName+"\');\">" + suiteName + 
+            "</span></td><td VALIGN='top'><span id='"+suiteName+"Links' align=\"right\" style='top:0px;float:right;paddingRight:8px;'>"+
+            "<a class='ui-state-default ui-corner-all suiteButton' href=\"#\" onclick=\"windmill.ui.playback.sendPlayBack(null,\'" + suiteName + 
+            "\')\">play</a>&nbsp<a class='ui-state-default ui-corner-all suiteButton' href=\"#\" onclick=\"windmill.ui.remote.saveSuite(\'" + suiteName + 
+            "\')\">save</a>&nbsp<a class='ui-state-default ui-corner-all suiteButton' href=\"#\" onclick=\"windmill.ui.remote.deleteAction(\'" + suiteName + 
+            "\')\">delete</a>&nbsp<a class='ui-state-default ui-corner-all suiteButton' href=\"#\" onclick=\"javascript:windmill.ui.toggleCollapse(\'" + suiteName + 
+            "\')\">toggle</a>&nbsp<a class='ui-state-default ui-corner-all suiteButton' href=\"#\" onclick=\"windmill.ui.currentSuite=\'"+suiteName+
+            "\'\">select</a></span>&nbsp;&nbsp;</td></tr></table>";
 
             //Append the new suite to the IDE
             $('ideForm').appendChild(suite);
-
+            
+            //Make the suites and actions draggable
+            jQuery(suite).sortable({items: "div", axis: "y", cancel: '.suiteTitleDiv,input,select,option,img'});
+            jQuery($('ideForm')).sortable({items:".suite", axis: "y", cancel: '.action,.suiteTitleDiv,input,select,option,a,img'});
+ 
+            //minimize the last suite
             try {
-                var h = $(suite.id).previousSibling.style.height;
-                //If the last suite is expanded, collapse it
-                if (h != '18px') { windmill.ui.toggleCollapse($(suite.id).previousSibling.id); }
+              var h = $(suite.id).previousSibling.style.height;
+              //If the last suite is expanded, collapse it
+              if (h != '22px') { 
+                windmill.ui.toggleCollapse($(suite.id).previousSibling.id); 
+              }
             } catch(err) { }
-
         }
         return suite;
 
@@ -278,20 +323,20 @@ windmill.ui.remote = new function() {
             var langSI = $('suiteSaveFormat').selectedIndex;
             var lang = $('suiteSaveFormat')[langSI].value;
 
-            var json_object = new json_call('1.1', 'create_save_file');
+            var jsonObject = new jsonCall('1.1', 'create_save_file');
             var params_obj = {};
             params_obj.transformer = lang;
             params_obj.suite_name = id;
             params_obj.tests = testArray;
-            json_object.params = params_obj;
+            jsonObject.params = params_obj;
 
             if (windmill.browser.isOpera){
-              var json_string = fleegix.json.serialize(json_object)
+              var jsonString = fleegix.json.serialize(jsonObject)
             }
             else {
-              var json_string = JSON.stringify(json_object);
+              var jsonString = JSON.stringify(jsonObject);
             }
-            fleegix.xhr.doPost(respRun, '/windmill-jsonrpc/', json_string);
+            fleegix.xhr.doPost(respRun, '/windmill-jsonrpc/', jsonString);
 
         }
         else {
@@ -299,6 +344,17 @@ windmill.ui.remote = new function() {
         }
     };
 
+    this.buildActionButtons = function(id){
+      var htmlStr = '<a alt="Start Playback" href="#">\
+      <img onclick="windmill.ui.playback.sendPlayBack(\'' + id + 
+      '\')" src="img/play.png"></a>&nbsp;<a alt="Delete Action" href="#">' + 
+      '<img onclick="windmill.ui.remote.deleteAction(\'' + id + '\')"  ' + 
+      'src="img/trash.png"></a>&nbsp;<a onclick="windmill.ui.remote.addActionAbove(\'' + id + 
+      '\')" href="#"><img src="img/addup.png"></a>&nbsp;<a onclick="windmill.ui.remote.addActionBelow(\'' + id + 
+      '\')" href="#"><img src="img/adddown.png"></a>';
+      return htmlStr;
+    }
+
     //This function takes a method and it's params and returns a DOM
     //Element representing that action for the UI
     this.buildAction = function(method, params) {
@@ -315,7 +371,13 @@ windmill.ui.remote = new function() {
 
         //var action = this.constructAction(method,'','',windmill.registry.methods[method].option,parms[windmill.registry.methods[method].option]);
         var action = document.createElement('div');
-        action.className = "action";
+        action.className = "ui-state-highlight ui-corner-all action";
+        if (!windmill.browser.isIE){
+          action.style.border = "1px solid lightgray";
+        }
+        else {
+          action.style.border = "1px solid #aaa";
+        }
         
         //if the user turns on the option to run actions by hitting enter
         var catchEnter = function(e){
@@ -351,18 +413,13 @@ windmill.ui.remote = new function() {
             i0.type = 'text';
             i0.id = action.id + 'method';
             i0.className = 'texta';
-            i0.size = '40';
+            //i0.size = '40';
+            //i0.style.width = "100%";
             i0.setAttribute('value', method);
             c.appendChild(i0);
 
-            c.innerHTML += '&nbsp&nbsp&nbsp&nbsp<a alt="Start Playback" href="#"><img border=0 onclick="windmill.ui.playback.sendPlayBack(\'' + action.id + 
-            '\')" style="height:18px;width:18px;" src="img/play.png"></a><a alt="Delete Action" href="#">' + 
-            '<img border=0 onclick="windmill.ui.remote.deleteAction(\'' + action.id + '\')" style="height:18px;width:18px;" ' + 
-            'src="img/trash.png"></a>';
+            c.innerHTML = this.buildActionButtons(action.id);
 
-            c.innerHTML += '<a onclick="windmill.ui.remote.addActionAbove(\'' + action.id + 
-            '\')" href="#"><img border=0 src="img/addup.png"></a><a onclick="windmill.ui.remote.addActionBelow(\'' + action.id + 
-            '\')" href="#"><img border=0 src="img/adddown.png"></a>';
             r.appendChild(c);
 
             //This makes it look better in IE
@@ -393,8 +450,8 @@ windmill.ui.remote = new function() {
 
 
         var r = document.createElement("tr");
+        r.style.fontWeight = "bold";
         var c = document.createElement("td");
-
         c.innerHTML += 'Method: ';
         r.appendChild(c);
         //Setup the method drop down
@@ -420,17 +477,14 @@ windmill.ui.remote = new function() {
             s.appendChild(o);
         }
         s.setAttribute("onchange", "windmill.ui.remote.methodChange('" + action.id + "');");
-
+        
         var c = document.createElement("td");
-        c.colSpan = "2";
         c.appendChild(s);
-
-        c.innerHTML += '&nbsp&nbsp&nbsp&nbsp&nbsp<a alt="Start Playback" href="#"><img border=0 onclick="windmill.ui.playback.sendPlayBack(\'' + action.id + 
-        '\')" style="height:18px;width:18px;" src="img/play.png"></a><a alt="Delete Action" href="#">' + 
-        '<img border=0 onclick="windmill.ui.remote.deleteAction(\'' + action.id + '\')" style="height:18px;width:18px;" ' + 
-        'src="img/trash.png"></a><a onclick="windmill.ui.remote.addActionAbove(\'' + action.id + 
-        '\')" href="#"><img border=0  src="img/addup.png"></a><a onclick="windmill.ui.remote.addActionBelow(\'' + action.id + 
-        '\')" href="#"><img border=0  src="img/adddown.png"></a>';
+        r.appendChild(c);
+        
+        var c = document.createElement("td");
+        c.style.textAlign = "center";
+        c.innerHTML = this.buildActionButtons(action.id);
 
         r.appendChild(c);
         t.appendChild(r);
@@ -443,6 +497,7 @@ windmill.ui.remote = new function() {
             var r = document.createElement("tr");
             r.id = action.id + 'locatorRow';
             var c = document.createElement("td");
+            c.style.fontWeight = "bold";
             c.innerHTML += 'Locater: ';
             r.appendChild(c);
 
@@ -491,9 +546,9 @@ windmill.ui.remote = new function() {
             i0.id = action.id + 'locator';
             //in firefox there was a bug moving the focus to the element we clicked, not sure why
             //but this seems to fix it. 
-            if (!windmill.browser.isIE) {
+            if (!windmill.browser.isIE6x) {
                 i0.setAttribute('onFocus', 'windmill.ui.remote.setRemoteElem(\'' + i0.id + '\')');
-                i0.setAttribute('onClick', '$(\'' + i0.id + '\').focus();');
+                //i0.setAttribute('onClick', '$(\'' + i0.id + '\').focus();');
             }
         
             c.appendChild(i0);
@@ -508,6 +563,8 @@ windmill.ui.remote = new function() {
             var r = document.createElement("tr");
             r.id = action.id + 'optionRow';
             var c = document.createElement("td");
+            c.style.fontWeight = "bold";
+            
             if (windmill.browser.isIE) {
                 c.innerHTML += '<br>Option: ';
             }
@@ -534,10 +591,13 @@ windmill.ui.remote = new function() {
             }
             //if the options are a comma delimited list, build the drop down
             else if (windmill.registry.methods[method].option.indexOf(',') != -1){
-              optArr = windmill.registry.methods[method].option.split(',');
+              var optArr = windmill.registry.methods[method].option.split(',');
               //for (opt in optArr){
               for (var opt = 0; opt < optArr.length; opt++){
-                newOpt = document.createElement('option');
+                var newOpt = document.createElement('option');
+                if (params[optArr[opt]]){
+                  newOpt.selected = true;
+                }
                 newOpt.value = optArr[opt];
                 newOpt.innerHTML = optArr[opt];
                 s2.appendChild(newOpt);
@@ -575,7 +635,8 @@ windmill.ui.remote = new function() {
             var i1 = document.createElement('input');
             i1.name = 'optValue';
             i1.className = 'texta';
-            i1.size = '40';
+            //i1.size = '40';
+            //i1.style.width = "100%";
             
             //if the action had a special flag, dragDropElemToElem
             if (windmill.ui.remote.optionValue != undefined){
@@ -601,15 +662,16 @@ windmill.ui.remote = new function() {
             
             //give the value input an id
             i1.id = action.id + 'option';
-            if (!windmill.browser.isIE) {
+            if (!windmill.browser.isIE6x) {
                 i1.setAttribute('onFocus', 'windmill.ui.remote.setRemoteElemOption(\'' + i1.id + '\')');
-                i1.setAttribute('onClick', '$(\'' + i1.id + '\').focus();');                
+                //i1.setAttribute('onClick', '$(\'' + i1.id + '\').focus();');                
             }
             c.appendChild(i1);
             r.appendChild(c);
             t.appendChild(r);
         }
-
+        
+        //stick the action in the IDE
         action.appendChild(t);
         if (windmill.browser.isIE) {
             action.innerHTML = t.innerHTML;
