@@ -21,14 +21,14 @@ windmill.registry = new function () {
 };
 
 //Setup all the current methods supported
-windmill.registry.locator = ['id','link','xpath','jsid', 'name','value','classname', 'tagname'];
+windmill.registry.locator = ['id','link','xpath','jsid', 'name','value','classname', 'tagname','label'];
 //windmill.registry.locator.push('id','link','xpath','jsid', 'name','classname', 'tagname');
 
 for( loc in windmill.registry.locator ){
   windmill.registry.option.push('opt'+loc);
 }
 
-windmill.registry.option.push('text','url','option','validator','destination','stopOnFailure', 'milliseconds', 'timeout','js', 'status','domain', 'coords', 'pixels');
+windmill.registry.option.push('text','url','option','validator','destination','stopOnFailure', 'milliseconds', 'timeout','js', 'status','domain', 'coords', 'pixels', 'val');
 
 //Setup method registry
 windmill.registry.methods['-- Mouse --']        = {'locator': false, 'option': false, 'section': true};
@@ -45,9 +45,12 @@ windmill.registry.methods['dragDropAbs']         = {'locator': true,'option': 'c
 windmill.registry.methods['dragDropElemToElem']  = {'locator': true,'option': true, 'optionIsLocator': true};
 windmill.registry.methods['radio']               = {'locator': true, 'option': false };
 windmill.registry.methods['check']               = {'locator': true, 'option': false };
-windmill.registry.methods['select']              = {'locator': true, 'option': 'option,value'};
+windmill.registry.methods['select']              = {'locator': true, 'option': 'option,val,index'};
 windmill.registry.methods['-- Keyboard --']      = {'locator': false, 'option': false, 'section': true};
 windmill.registry.methods['type']                = {'locator': true, 'option': 'text'};
+windmill.registry.methods['keyPress']            = {'locator': true, 'option': 'options'};
+windmill.registry.methods['keyDown']            = {'locator': true, 'option': 'options'};
+windmill.registry.methods['keyUp']            = {'locator': true, 'option': 'options'};
 windmill.registry.methods['-- Browser --']       = {'locator': false, 'option': false, 'section': true};
 windmill.registry.methods['open']                = {'locator': false, 'option': 'url' };
 windmill.registry.methods['goBack']              = {'locator': false, 'option': false };
@@ -58,16 +61,25 @@ windmill.registry.methods['-- Waits --']         = {'locator': false, 'option':
 windmill.registry.methods['waits.sleep']         = {'locator': false, 'option': 'milliseconds' };
 windmill.registry.methods['waits.forElement']     = {'locator': true, 'option': 'timeout' };
 windmill.registry.methods['waits.forNotElement']  = {'locator': true, 'option': 'timeout' };
+windmill.registry.methods['waits.forJS']        = {'locator': false, 'option': 'js' };
+windmill.registry.methods['waits.forElementProperty']    = {'locator': true, 'option': 'option' };
 windmill.registry.methods['waits.forPageLoad']    = {'locator': false, 'option': 'timeout' };
 windmill.registry.methods['-- Other --']        = {'locator': false, 'option': false, 'section': true};
-windmill.registry.methods['setTestWindow']       = {'locator': false, 'option': 'path'};
-windmill.registry.methods['setOptions']         = {'locator': false, 'option':'stopOnFailure'};
+windmill.registry.methods['closeWindow']   = {'locator': false, 'option': false};
+windmill.registry.methods['complex']            = {'locator': false, 'option': false };
+windmill.registry.methods['execJsInTestWindow']   = {'locator': false, 'option': 'js' };
+windmill.registry.methods['execIDEJS']            = {'locator': false, 'option': 'js' };
+windmill.registry.methods['revertWindow']   = {'locator': false, 'option': false};
 windmill.registry.methods['reWriteAlert']       = {'locator': false, 'option': false };
+windmill.registry.methods['setPromptDefault']       = {'locator': false, 'option': 'val' };
+windmill.registry.methods['setTestWindow']      = {'locator': false, 'option': 'path'};
+windmill.registry.methods['setWindowByTitle']   = {'locator': false, 'option': 'title'};
+windmill.registry.methods['setDocDomain']           = {'locator': false, 'option': 'domain' };
+windmill.registry.methods['setOptions']         = {'locator': false, 'option':'stopOnFailure'};
 windmill.registry.methods['storeURL']           = {'locator': true, 'option': false };
 windmill.registry.methods['storeVarFromJS']     = {'locator': false, 'option': 'options' };
+windmill.registry.methods['storeVarFromIDEJS']     = {'locator': false, 'option': 'options' };
 windmill.registry.methods['storeVarFromLocAttrib']     = {'locator': true, 'option': 'options' };
-windmill.registry.methods['setDocDomain']           = {'locator': false, 'option': 'domain' };
-windmill.registry.methods['complex']            = {'locator': false, 'option': false };
 windmill.registry.methods['-- Asserts --']        = {'locator': false, 'option': false, 'section': true};
 windmill.registry.methods['asserts.assertJS']    = {'locator': false, 'option': 'js' };
 windmill.registry.methods['asserts.assertElemJS']    = {'locator': true, 'option': 'js' };
